function temmask = tem_sampling_generation(Np, Nfr, Nnav, Nsam)

% Generating the temporal sampling mask
% Inputs:
% Np: number of phase encodings
% Nfr: number of temporal frames
% Nnav: number of phase encodings for navigator signal
% Nsam: number of samples acquired at each k-space location
%
% Output:
% temmask: temporal sampling mask
% 
% Bo Zhao, 11/27/2011 zhaobouiuc@gmail.com

temmask = zeros(Np, Nfr);
nav_ind = Np/2-Nnav/2+1:Np/2+Nnav/2;
for ii = 1:Np
    if (find(ii == nav_ind))
        temmask(ii, :) = ones(1, Nfr);
    else
        temp = zeros(1, Nfr);
        ind = randperm(Nfr);
        temp(ind(1:Nsam)) = 1;
        temmask(ii, :) = temp;
    end
end
temmask = logical(temmask);